# gf180 0.2.0 (Legacy/Deprecated)

GlobalFoundries 180nm MCU based on [Google open source PDK](https://github.com/google/globalfoundries-pdk-libs-gf180mcu_fd_pr)

**IMPORTANT: This package is now a legacy alias for the `gf180mcu` package. Please use `gf180mcu` directly in new code.**

This package now simply redirects all functionality to the `gf180mcu` package. It is kept for backwards compatibility only and will be removed in a future version.
